aboutsummaryrefslogtreecommitdiffhomepage
path: root/test/zerosized.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'test/zerosized.cpp')
-rw-r--r--test/zerosized.cpp2
1 files changed, 1 insertions, 1 deletions
diff --git a/test/zerosized.cpp b/test/zerosized.cpp
index a50922fdc..06e31cc09 100644
--- a/test/zerosized.cpp
+++ b/test/zerosized.cpp
@@ -51,7 +51,7 @@ template<typename VectorType> void zeroSizedVector()
if (VectorType::SizeAtCompileTime == Dynamic)
{
VERIFY(t1.size() == 0);
- VectorType t2(long(0)); // long disambiguates with 0-the-null-pointer (error with gcc 4.4)
+ VectorType t2(DenseIndex(0)); // DenseIndex disambiguates with 0-the-null-pointer (error with gcc 4.4 and MSVC8)
VERIFY(t2.size() == 0);
}
}